An octoprint plugin to automatically switch off the power to your 3d-printer.

Alpha release is WIP.


### Usage
TODO

### Installation
TODO

### Development resources
[developer setup](./developer_setup.md)
